//+------------------------------------------------------------------+
//|                                                         AOAC.mq4 |
//|                      Copyright  2010, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2010, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

#property indicator_separate_window
#property indicator_buffers 3
#property indicator_color1  Yellow
#property indicator_color2  DodgerBlue
#property indicator_color3  Magenta
#property indicator_width1  2
#property indicator_width2  2
#property indicator_width3  2
#property indicator_minimum 30.0
#property indicator_maximum 60.0

extern bool   alertsOn         = true;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = false;
extern bool   alertsNotify     = true;
extern bool   alertsEmail      = true;
extern string soundfile        = "alert2.wav"; 
extern bool   ShowArrows       = false;
extern string arrowsIdentifier = "AOAC Arrows";
extern color  arrowsUpColor    = LimeGreen;
extern color  arrowsDnColor    = Red;
extern color  arrowsNuColor    = Gray;
extern color  arrowsUpCode     = 241;
extern color  arrowsDnCode     = 242;
extern color  arrowsNuCode     = 108;


 
double aNu[];
double aUp[];
double aDn[];
double trend[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   IndicatorBuffers(4);
   SetIndexBuffer(0,aNu); SetIndexStyle(0,DRAW_ARROW); SetIndexArrow(0,167);
   SetIndexBuffer(1,aUp); SetIndexStyle(1,DRAW_ARROW); SetIndexArrow(1,167);
   SetIndexBuffer(2,aDn); SetIndexStyle(2,DRAW_ARROW); SetIndexArrow(2,167);
   SetIndexBuffer(3,trend);
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
//
//

int deinit()
{
   deleteArrows();
    
return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int i, limit;
   
   int counted_bars=IndicatorCounted();
   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;
   limit = MathMin(Bars-counted_bars,Bars-1);
//----
   for(i=limit; i>=0; i--) 
   {
      double dcAC = iAC(NULL,0,i+1);
      double dpAC = iAC(NULL,0,i+2);
      double dcAO = iAO(NULL,0,i+1);
      double dpAO = iAO(NULL,0,i+2);
      
      aUp[i] = EMPTY_VALUE;
      aDn[i] = EMPTY_VALUE;
      aNu[i] = EMPTY_VALUE;
      trend[i] = 0;
      if (dcAC >= dpAC && dcAO >= dpAO) trend[i] = 1;
      if (dcAC <  dpAC && dcAO <  dpAO) trend[i] =-1;
      if (dcAC == dpAC && dcAO == dpAO) trend[i] = 0;
      if (trend[i] == 1) aUp[i+1] = 45;
      if (trend[i] ==-1) aDn[i+1] = 45;
      if (trend[i] == 0) aNu[i+1] = 45;
      manageArrow(i);  
   }
manageAlerts();
return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

void manageAlerts()
{
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1; 
      if (trend[whichBar] != trend[whichBar+1])
      {
         if (trend[whichBar] == 1)                          doAlert(whichBar,"up");
         if (trend[whichBar] ==-1)                          doAlert(whichBar,"down");
         if (trend[whichBar] == 0 && trend[whichBar+1]== 1) doAlert(whichBar,"back from up now neutral");
         if (trend[whichBar] ==-0 && trend[whichBar+1]==-1) doAlert(whichBar,"back from down now neutral");
      }         
   }
}   

//
//
//
//
//

void doAlert(int forBar, string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[forBar]) {
          previousAlert  = doWhat;
          previousTime   = Time[forBar];

          //
          //
          //
          //
          //

           message =  StringConcatenate(Symbol(),TimeToStr(TimeLocal(),TIME_SECONDS)," AOAC ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," AOAC " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol(), Period(), " AOAC "),message);
             if (alertsSound)   PlaySound("alert2.wav");
      }
}

//
//
//
//
//

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

void manageArrow(int i)
{
   if (ShowArrows)
   {
      deleteArrow(Time[i]);
      if (trend[i]!=trend[i+1])
      {
         if (trend[i] == 1)                   drawArrow(i,arrowsUpColor,arrowsUpCode,false);
         if (trend[i] ==-1)                   drawArrow(i,arrowsDnColor,arrowsDnCode, true);
         if (trend[i] == 0 && trend[i+1]== 1) drawArrow(i,arrowsNuColor,arrowsNuCode,false);
         if (trend[i] == 0 && trend[i+1]==-1) drawArrow(i,arrowsNuColor,arrowsNuCode, true);
      }
   }
}               

//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+Time[i];
   double gap  = 3.0*iATR(NULL,0,20,i)/4.0;   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i]+ gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i] - gap);
}

//
//
//
//
//

void deleteArrows()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
}

//
//
//
//
//

void deleteArrow(datetime time)
{
   string lookFor = arrowsIdentifier+":"+time; ObjectDelete(lookFor);
}


